@@ -17,20 +17,27 @@
 
   # Date and POSIXct classes need to be formatted
   indDT <- which(sapply(y, class) == "Date")
-  dateFormat <- createCellStyle(wb, dataFormat="m/d/yyyy")
-  for (ic in indDT){
-    lapply(cells[1:nrow(cells),colIndex[ic]], setCellStyle, dateFormat)
+  if (length(indDT) > 0) {
+    dateFormat <- CellStyle(wb) + DataFormat("m/d/yyyy")
+    for (ic in indDT){
+      lapply(cells[1:nrow(cells),colIndex[ic]], setCellStyle, dateFormat)
+    }
   }
   indDT <- which(sapply(y, class) == "POSIXct")
-  datetimeFormat <- createCellStyle(wb, dataFormat="m/d/yyyy h:mm:ss;@")
-  for (ic in indDT){
-    lapply(cells[1:nrow(cells),colIndex[ic]], setCellStyle, datetimeFormat)
+  if (length(indDT) > 0) {
+    datetimeFormat <- CellStyle(wb) + DataFormat("m/d/yyyy h:mm:ss;@")
+    for (ic in indDT){
+      lapply(cells[1:nrow(cells),colIndex[ic]], setCellStyle, datetimeFormat)
+    }
   }
 
 }
 
 
-write.xlsx <- function(x, file, sheetName="Sheet 1", formatTemplate=NULL,
+#######################################################################
+# High-level API
+#
+write.xlsx <- function(x, file, sheetName="Sheet1",
   col.names=TRUE, row.names=TRUE, append=FALSE)
 {
   if (!is.data.frame(x))
@@ -65,29 +72,10 @@ write.xlsx <- function(x, file, sheetName="Sheet 1", formatTemplate=NULL,
   .write_block(wb, sheet, x, rowIndex, colIndex)
   saveWorkbook(wb, file)
 
-  
-##   # add a general format template
-##   if (!is.null(formatTemplate)){
-##     cat("formatTemplate is not yet supported.  Patches welcome.")
-##     wb <- wb  # call the custom function
-##   }
-    
-  
   invisible()
 }
 
 
 #  .jcall("java/lang/System", "V", "gc")  # doesn't do anything!
 
-##  don't do it with blocks, it's silly
-##   noBlocks <- trunc(nrow(x)/.BLOCK_SIZE)+1
-##   for (b in seq_len(noBlocks)){
-##     if (b > 1){
-##       wb <- loadWorkbook(file)
-##       sheet <- getSheets(wb)[[sheetName]]
-##     }
-##     indR <- ((b-1)*.BLOCK_SIZE+1):min(nrow(x), b*.BLOCK_SIZE)
-##     rowIndex <- indR + jOffset
-##     .write_block(sheet, x[indR,], rowIndex, colIndex)
-##     saveWorkbook(wb, file)
-##   }  
+
